# Attribution

The Norwegian stopword dictonary (Norwegian_NRK.txt) is sourced from the Norwegian Broadcasting Corporation's [samnorsk](https://github.com/nrkno/samnorsk) repository and licensed under the MIT License.

The stopword dictionaries for the Sami languages (sme.txt, sma.txt, smj.txt, sms.txt, smn.txt) are sourced from [Giellatekno](https://giellatekno.uit.no/lex.en.html) and licensed under CC BY-SA 1.0.

All other stoplists are from [Justext](https://corpus.tools/wiki/Justext), licensed under the BSD license, slightly adopted (removed non-alphanumeric characters).
